@@ -27,6 +27,7 @@ from spark_pipeline_framework.transformers.framework_mapping_runner.v1.framework
 from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import (
     FrameworkTransformer,
 )
+from spark_pipeline_framework.utilities.file_modes import FileWriteModes
 from spark_pipeline_framework.utilities.spark_data_frame_helpers import (
     spark_is_data_frame_empty,
 )
@@ -39,8 +40,8 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         self,
         # add your parameters here (be sure to add them to setParams below too)
         transformer: ProxyBase,
-        func_get_path: Callable[[str, str], str],
-        func_get_response_path: Callable[[str, str], str],
+        func_get_path: Callable[[str, str, Optional[str]], str],
+        func_get_response_path: Callable[[str, str, Optional[str]], str],
         fhir_server_url: str,
         source_entity_name: str,
         fhir_validation_url: Optional[str] = None,
@@ -54,6 +55,7 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         auth_scopes: Optional[List[str]] = None,
         progress_logger: Optional[ProgressLogger] = None,
         send_to_fhir: Optional[bool] = True,
+        mode: str = FileWriteModes.MODE_ERROR,
     ):
         """
         Runs the auto-mappers, saves the result to Athena db and then sends the results to fhir server
@@ -74,21 +76,22 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
 
         self.logger = get_logger(__name__)
         self.logger.info(
-            f"Parameters={json.dumps({str(key): str(value) for key, value in parameters.items()}) if parameters else 'None'}"
+            f"Parameters="
+            + f"{json.dumps({str(key): str(value) for key, value in parameters.items()}) if parameters else 'None'}"
         )
 
         # add a param
         self.transformer: Param[ProxyBase] = Param(self, "transformer", "")
         self._setDefault(transformer=transformer)
 
-        self.func_get_path: Param[Callable[[str, str], str]] = Param(
+        self.func_get_path: Param[Callable[[str, str, Optional[str]], str]] = Param(
             self, "func_get_path", ""
         )
         self._setDefault(func_get_path=func_get_path)
 
-        self.func_get_response_path: Param[Callable[[str, str], str]] = Param(
-            self, "func_get_response_path", ""
-        )
+        self.func_get_response_path: Param[
+            Callable[[str, str, Optional[str]], str]
+        ] = Param(self, "func_get_response_path", "")
         self._setDefault(func_get_response_path=func_get_response_path)
 
         self.fhir_server_url: Param[str] = Param(self, "fhir_server_url", "")
@@ -127,14 +130,17 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         self.send_to_fhir: Param[Optional[bool]] = Param(self, "send_to_fhir", "")
         self._setDefault(send_to_fhir=send_to_fhir)
 
+        self.mode: Param[str] = Param(self, "mode", "")
+        self._setDefault(mode=mode)
+
         kwargs = self._input_kwargs
         self.setParams(**kwargs)
 
     def _transform(self, df: DataFrame) -> DataFrame:
         transformer: ProxyBase = self.getTransformer()
-        func_get_path: Callable[[str, str], str] = self.getFuncGetPath()
+        func_get_path: Callable[[str, str, Optional[str]], str] = self.getFuncGetPath()
         func_get_response_path: Callable[
-            [str, str], str
+            [str, str, Optional[str]], str
         ] = self.getFuncGetResponsePath()
         fhir_server_url: str = self.getFhirServerUrl()
         fhir_validation_url: Optional[str] = self.getFhirValidationServerUrl()
@@ -152,6 +158,8 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         auth_scopes: Optional[List[str]] = self.getAuthScopes()
         send_to_fhir: Optional[bool] = self.getSendToFhir()
 
+        mode: str = self.getOrDefault(self.mode)
+
         self.logger.info(f"Calling {fhir_server_url} with client_id={auth_client_id}")
 
         if len(transformer.transformers) == 0:
@@ -179,9 +187,11 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
                     assert first_row
                     # noinspection PyPep8Naming
                     resourceType: str = first_row["resourceType"]
-                    fhir_resource_path: str = func_get_path(view, resourceType)
+                    fhir_resource_path: str = func_get_path(
+                        view, resourceType, self.loop_id
+                    )
                     fhir_resource_response_path: str = func_get_response_path(
-                        view, resourceType
+                        view, resourceType, self.loop_id
                     )
                     # export as FHIR to local fhir_resource_path
                     FhirExporter(
@@ -190,6 +200,7 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
                         parameters=parameters,
                         progress_logger=progress_logger,
                         name=f"{name}_fhir_exporter",
+                        mode=mode,
                     ).transform(df)
                     if fhir_resource_path.startswith("s3") and athena_schema:
                         # create table in Athena
@@ -224,6 +235,7 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
                             auth_login_token=auth_login_token,
                             auth_scopes=auth_scopes,
                             name=f"{name}_fhir_sender",
+                            mode=mode,
                         ).transform(df)
         return df
 
@@ -232,11 +244,11 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         return self.getOrDefault(self.transformer)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getFuncGetPath(self) -> Callable[[str, str], str]:
+    def getFuncGetPath(self) -> Callable[[str, str, Optional[str]], str]:
         return self.getOrDefault(self.func_get_path)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getFuncGetResponsePath(self) -> Callable[[str, str], str]:
+    def getFuncGetResponsePath(self) -> Callable[[str, str, Optional[str]], str]:
         return self.getOrDefault(self.func_get_response_path)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
